@@ -181,7 +181,7 @@ If `header_image` is not provided, use this text when generating the image
 (Windows only). Defaults to `name`.
 '''),
 
-    ('add_to_path_default',    False, bool, '''
+    ('initialize_by_default',    False, bool, '''
 Default choice for whether to add the installation to the PATH environment
 variable. The user is still able to change this during interactive
 installation.
