@@ -1,4 +1,4 @@
-# (c) 2012-2016 Continuum Analytics, Inc. / http://continuum.io
+# (c) 2012-2016 Anaconda, Inc. / https://anaconda.com
 # All Rights Reserved
 #
 # conda is distributed under the terms of the BSD 3-clause license.
@@ -228,8 +228,6 @@ def create_meta(prefix, dist, info_dir, extra_info):
     meta_dir = join(prefix, 'conda-meta')
     if not isdir(meta_dir):
         os.makedirs(meta_dir)
-        with open(join(meta_dir, 'history'), 'w') as fo:
-            fo.write('')
     with open(join(meta_dir, dist + '.json'), 'w') as fo:
         json.dump(meta, fo, indent=2, sort_keys=True)
 
