@@ -1,25 +1,43 @@
-# (c) 2016 Continuum Analytics, Inc. / http://continuum.io
+# (c) 2016 Anaconda, Inc. / https://anaconda.com
 # All Rights Reserved
 #
 # constructor is distributed under the terms of the BSD 3-clause license.
 # Consult LICENSE.txt or http://opensource.org/licenses/BSD-3-Clause.
 
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import os
-import sys
 from os.path import abspath, basename, expanduser, isdir, join
+import sys
 
-from libconda.config import subdir as cc_platform
-
-from constructor.install import yield_lines
-import constructor.fcp as fcp
-import constructor.construct as construct
-
+from .conda_interface import cc_platform
+from .construct import parse as construct_parse, verify as construct_verify
+from .fcp import main as fcp_main
+from .install import yield_lines
 
 DEFAULT_CACHE_DIR = os.getenv('CONSTRUCTOR_CACHE', '~/.conda/constructor')
 
 
+def set_installer_type(info):
+    osname, unused_arch = info['_platform'].split('-')
+
+    if not info.get('installer_type'):
+        os_map = {'linux': 'sh', 'osx': 'sh', 'win': 'exe'}
+        info['installer_type'] = os_map[osname]
+
+    allowed_types = 'sh', 'pkg', 'exe'
+    itype = info['installer_type']
+    if itype not in allowed_types:
+        sys.exit("Error: invalid installer type '%s',\n"
+                 "allowed types are: %s" % (itype, allowed_types))
+
+    if ((osname == 'linux' and itype != 'sh') or
+        (osname == 'osx' and itype not in ('sh', 'pkg')) or
+        (osname == 'win' and itype != 'exe')):
+        sys.exit("Error: cannot create '.%s' installer for %s" % (itype,
+                                                                  osname))
+
+
 def get_output_filename(info):
     try:
         return info['installer_filename']
@@ -29,7 +47,7 @@ def get_output_filename(info):
     osname, arch = info['_platform'].split('-')
     os_map = {'linux': 'Linux', 'osx': 'MacOSX', 'win': 'Windows'}
     arch_name_map = {'64': 'x86_64', '32': 'x86'}
-    ext = 'exe' if osname == 'win' else 'sh'
+    ext = info['installer_type']
     return '%s-%s-%s.%s' % ('%(name)s-%(version)s' % info,
                             os_map.get(osname, osname),
                             arch_name_map.get(arch, arch),
@@ -37,7 +55,8 @@ def get_output_filename(info):
 
 
 def main_build(dir_path, output_dir='.', platform=cc_platform,
-               verbose=True, cache_dir=DEFAULT_CACHE_DIR):
+               verbose=True, cache_dir=DEFAULT_CACHE_DIR,
+               dry_run=False):
     print('platform: %s' % platform)
     cache_dir = abspath(expanduser(cache_dir))
     try:
@@ -45,26 +64,33 @@ def main_build(dir_path, output_dir='.', platform=cc_platform,
     except ValueError:
         sys.exit("Error: invalid platform string '%s'" % platform)
 
-    if osname in ('linux', 'osx'):
-        if sys.platform == 'win32':
-            sys.exit("Error: Cannot create .sh installer on Windows platform.")
-        from constructor.shar import create
-    elif osname == 'win':
-        if sys.platform != 'win32':
-            sys.exit("Error: Cannot create Windows .exe installer on "
-                     "non-Windows platform.")
-        from constructor.winexe import create
-    else:
-        sys.exit("Error: invalid OS name '%s'" % osname)
-
     construct_path = join(dir_path, 'construct.yaml')
-    info = construct.parse(construct_path, platform)
-    construct.verify(info)
+    info = construct_parse(construct_path, platform)
+    construct_verify(info)
     info['_platform'] = platform
     info['_download_dir'] = join(cache_dir, platform)
+    set_installer_type(info)
+
+    if info['installer_type'] == 'sh':
+        if sys.platform == 'win32':
+            sys.exit("Error: Cannot create .sh installer on Windows.")
+        from .shar import create
+    elif info['installer_type'] == 'pkg':
+        if sys.platform != 'darwin':
+            sys.exit("Error: Can only create .pkg installer on OSX.")
+        from .osxpkg import create
+    elif info['installer_type'] == 'exe':
+        if sys.platform != 'win32':
+            sys.exit("Error: Can only create .pkg installer on Windows.")
+        from .winexe import create
+
     if verbose:
         print('conda packages download: %s' % info['_download_dir'])
 
+    for key in ('welcome_image_text', 'header_image_text'):
+        if key not in info:
+            info[key] = info['name']
+
     for key in ('license_file', 'welcome_image', 'header_image', 'icon_image',
                 'pre_install', 'post_install'):
         if key in info:
@@ -84,10 +110,22 @@ def main_build(dir_path, output_dir='.', platform=cc_platform,
             if any((not s) for s in info[key]):
                 sys.exit("Error: found empty element in '%s:'" % key)
 
-    fcp.main(info, verbose=verbose)
+    fcp_main(info, verbose=verbose, dry_run=dry_run)
+    if dry_run:
+        print("Dry run, no installer created.")
+        return
 
     info['_outpath'] = join(output_dir, get_output_filename(info))
-    create(info)
+
+    # info has keys
+    # 'name', 'version', 'channels', 'exclude',
+    # '_platform', '_download_dir', '_outpath'
+    # 'specs': ['python 3.5*', 'conda', 'nomkl', 'numpy', 'scipy', 'pandas', 'notebook', 'matplotlib', 'lighttpd']
+    # 'license_file': '/Users/kfranz/continuum/constructor/examples/maxiconda/EULA.txt'
+    # '_dists': List[Dist]
+    # '_urls': List[Tuple[url, md5]]
+
+    create(info, verbose=verbose)
     if 0:
         with open(join(output_dir, 'pkg-list.txt'), 'w') as fo:
             fo.write('# installer: %s\n' % basename(info['_outpath']))
@@ -135,6 +173,11 @@ def main():
                  help="perform some self tests and exit",
                  action="store_true")
 
+    p.add_option('--dry-run',
+                 help="solve package specs but do not create installer",
+                 default=False,
+                 action="store_true")
+
     p.add_option('-v', '--verbose',
                  action="store_true")
 
@@ -145,7 +188,7 @@ def main():
     opts, args = p.parse_args()
 
     if opts.version:
-        from constructor import __version__
+        from . import __version__
         print('constructor version:', __version__)
         return
 
@@ -158,8 +201,8 @@ def main():
         return
 
     if opts.test:
-        import constructor.tests
-        constructor.tests.main()
+        from .tests import main as tests_main
+        tests_main()
         return
 
     if opts.debug:
@@ -174,7 +217,8 @@ def main():
         p.error("no such directory: %s" % dir_path)
 
     main_build(dir_path, output_dir=opts.output_dir, platform=opts.platform,
-               verbose=opts.verbose, cache_dir=opts.cache_dir)
+               verbose=opts.verbose, cache_dir=opts.cache_dir,
+               dry_run=opts.dry_run)
 
 
 if __name__ == '__main__':
