@@ -143,6 +143,7 @@ def make_nsi(info, dir_path):
                     ('URLS_TXT_FILE', 'urls.txt'),
                     ('POST_INSTALL', 'post_install.bat'),
                     ('CONDA_HISTORY', join('conda-meta', 'history')),
+                    ('REPODATA_RECORD', 'repodata_record.json'),
                     ('INDEX_CACHE', 'cache')]:
         replace[key] = join(dir_path, fn)
     for key in replace:
@@ -150,7 +151,7 @@ def make_nsi(info, dir_path):
 
     data = read_nsi_tmpl()
     ppd = ns_platform(info['_platform'])
-    ppd['add_to_path_default'] = info.get('add_to_path_default', None)
+    ppd['initialize_by_default'] = info.get('initialize_by_default', None)
     ppd['register_python_default'] = info.get('register_python_default', None)
     data = preprocess(data, ppd)
     data = fill_template(data, replace)
